/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.syncope.core.scheduling;

import java.util.List;
import org.identityconnectors.framework.common.objects.SyncDelta;
import org.quartz.JobExecutionException;
import org.syncope.client.mod.UserMod;
import org.syncope.client.to.UserTO;

/**
 * Interface for actions to be performed during SyncJob execution.
 */
public interface SyncJobActions {

    void beforeAll(List<SyncDelta> deltas)
            throws JobExecutionException;

    void beforeCreate(SyncDelta delta, UserTO user)
            throws JobExecutionException;

    void beforeUpdate(SyncDelta delta, UserTO user, UserMod userMod)
            throws JobExecutionException;

    void beforeDelete(SyncDelta delta, UserTO user)
            throws JobExecutionException;

    void after(SyncDelta delta, UserTO user, SyncResult result)
            throws JobExecutionException;

    void afterAll(List<SyncDelta> deltas, List<SyncResult> results)
            throws JobExecutionException;
}
